You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by js...@apache.org on 2006/09/21 07:27:55 UTC

svn commit: r448463 - in /incubator/tuscany/cpp/sca: runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/ runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/model/ runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/ runtime/extensions...

Author: jsdelfino
Date: Wed Sep 20 22:27:54 2006
New Revision: 448463

URL: http://svn.apache.org/viewvc?view=rev&rev=448463
Log:
Ported Web Service binding, samples and scenarios to Web Service Binding spec level 0.96

Modified:
    incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/Axis2Client.cpp
    incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/WSServiceBindingExtension.cpp
    incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/model/WSServiceBinding.cpp
    incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/model/WSServiceBinding.h
    incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/Axis2Service.cpp
    incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/WSReferenceBindingExtension.cpp
    incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/model/WSReferenceBinding.cpp
    incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/model/WSReferenceBinding.h
    incubator/tuscany/cpp/sca/runtime/extensions/ws/xsd/sca-binding-webservice.xsd
    incubator/tuscany/cpp/sca/samples/BigBank/bigbank.account/bigbank.account.composite
    incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/sca.composite
    incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator/sample.calculator.composite
    incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.demo/supplychain.demo.composite
    incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.logging/supplychain.logging.composite
    incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.manufacturer/supplychain.manufacturer.composite
    incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.retailer/supplychain.retailer.composite
    incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.warehouse/supplychain.warehouse.composite

Modified: incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/Axis2Client.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/Axis2Client.cpp?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/Axis2Client.cpp (original)
+++ incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/Axis2Client.cpp Wed Sep 20 22:27:54 2006
@@ -104,7 +104,7 @@
                     {
                         wsdlOperation =  wsdlDefinition->findOperation(
                             binding->getServiceName(),
-                            binding->getPortName(),
+                            binding->getEndpointName(),
                             operationName);
                     }
                     catch(SystemConfigurationException &ex)
@@ -191,10 +191,17 @@
                 axis2_options_t* options = axis2_options_create(env);
                 AXIS2_OPTIONS_SET_TO(options, env, endpoint_ref);
                 int soap_version = AXIOM_SOAP11;
-                if (wsdlOperation.getSoapVersion() == WSDLOperation::SOAP12)
+                if (binding->getSOAPVersion() == "1.2")
                 {
                     soap_version = AXIOM_SOAP12;
                 }
+                else
+                {
+                    if (wsdlOperation.getSoapVersion() == WSDLOperation::SOAP12)
+                    {
+                        soap_version = AXIOM_SOAP12;
+                    }
+                }
                 
                 AXIS2_OPTIONS_SET_SOAP_VERSION(options, env, soap_version);
                 AXIS2_OPTIONS_SET_ACTION(options, env, soap_action);
@@ -265,7 +272,7 @@
                     DataObjectPtr requestDO = dataFactory->create(wsdlOp.getInputTypeUri().c_str(), 
                         wsdlOp.getInputTypeName().c_str());
 
-                    // Go through data object to set the return value
+                    // Go through data object to set the input parameters
                     PropertyList pl = requestDO->getType().getProperties();
                 
                     if(pl.size() == 0)

Modified: incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/WSServiceBindingExtension.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/WSServiceBindingExtension.cpp?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/WSServiceBindingExtension.cpp (original)
+++ incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/WSServiceBindingExtension.cpp Wed Sep 20 22:27:54 2006
@@ -72,9 +72,19 @@
                 if (bindingType == "WebServiceBinding")
                 {
                     string uri = scdlBinding->getCString("uri");
-                    string port = scdlBinding->getCString("port");
+                    string endpoint = scdlBinding->getCString("endpoint");
+                    commonj::sdo::DataObjectList& soap = scdlBinding->getList("soapbinding");
+                    string version;
+                    if (soap.size()!=0)
+                    {
+                        version = soap.getCString(0);
+                    }
+                    else
+                    {
+                        version = "";
+                    }
 
-                    WSServiceBinding* serviceBinding = new WSServiceBinding(service, uri, port);
+                    WSServiceBinding* serviceBinding = new WSServiceBinding(service, uri, endpoint, version);
                     
                     return serviceBinding;
                 }

Modified: incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/model/WSServiceBinding.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/model/WSServiceBinding.cpp?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/model/WSServiceBinding.cpp (original)
+++ incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/model/WSServiceBinding.cpp Wed Sep 20 22:27:54 2006
@@ -30,59 +30,59 @@
         {
 
             // Constructor
-            WSServiceBinding::WSServiceBinding(Service* service, const string& uri, const string& port)
-                : ServiceBinding(service, uri), port(port)
+            WSServiceBinding::WSServiceBinding(Service* service, const string& uri, const string& endpoint, const string& version)
+                : ServiceBinding(service, uri), endpoint(endpoint), soapVersion(version)
             {
-                parsePort();
+                parseEndpoint();
                 
                 serviceWrapper = new WSServiceWrapper(service);
             }
 
-            void WSServiceBinding::parsePort()
+            void WSServiceBinding::parseEndpoint()
             {
-                // Port is of the form: <wsdl-namepace-uri>#wsdl.endpoint(<service-name>/<port-name>)
-                string::size_type hash = port.find("#");
+                // Endpoint is of the form: <wsdl-namepace-uri>#wsdl.endpoint(<service-name>/<endpoint-name>)
+                string::size_type hash = endpoint.find("#");
                 if (hash != string::npos)
                 {
                     // Found a hash
 
                     // Namepace is the part before the #
-                    wsdlNamespaceURL = port.substr(0, hash);
+                    wsdlNamespaceURL = endpoint.substr(0, hash);
 
                     
-                    if ( (hash+1) < port.length())
+                    if ( (hash+1) < endpoint.length())
                     {
                         // Check the next part is wsdl.endpoint( 
                         int ending = hash+15;
-                        string check = port.substr(hash+1, 14);
+                        string check = endpoint.substr(hash+1, 14);
                         if (check.compare("wsdl.endpoint(") == 0)
                         {
                             // Find the matching )
-                            int endBracket = port.find(")",ending);
+                            int endBracket = endpoint.find(")",ending);
                             if (endBracket-1 > ending+1)
                             {
-                                string serviceAndPort = port.substr(ending, endBracket-ending);
+                                string serviceAndEndpoint = endpoint.substr(ending, endBracket-ending);
                                 // Look for a '/'
-                                string::size_type slash = serviceAndPort.find("/");
+                                string::size_type slash = serviceAndEndpoint.find("/");
                                 if (slash != string::npos)
                                 {
-                                    serviceName = serviceAndPort.substr(0, slash);
+                                    serviceName = serviceAndEndpoint.substr(0, slash);
 
-                                    if ( (slash+1) < serviceAndPort.length())
+                                    if ( (slash+1) < serviceAndEndpoint.length())
                                     {
-                                        portName = serviceAndPort.substr(slash+1);
+                                        endpointName = serviceAndEndpoint.substr(slash+1);
                                     }
                                     else
                                     {
-                                        portName = "";
+                                        endpointName = "";
                                     }
 
                                 }
                                 else
                                 {
                                     // No '/' so all of it is the service name
-                                    serviceName = serviceAndPort;
-                                    portName = "";
+                                    serviceName = serviceAndEndpoint;
+                                    endpointName = "";
 
                                 }
                             }
@@ -90,14 +90,14 @@
                             {
                                 // Nothing between the ()
                                 serviceName = "";
-                                portName = "";
+                                endpointName = "";
                             }
                         }
                         else
                         {
                             // not the correct characters after the #, ignore the rest
                             serviceName = "";
-                            portName = "";
+                            endpointName = "";
                         }
                         
                     }
@@ -105,15 +105,15 @@
                     {
                         // Nothing after the hash
                         serviceName = "";
-                        portName = "";
+                        endpointName = "";
                     }
                 }
                 else
                 {
                     // No hash at all
-                    wsdlNamespaceURL = port;
+                    wsdlNamespaceURL = endpoint;
                     serviceName = "";
-                    portName = "";
+                    endpointName = "";
                 }
             }
 

Modified: incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/model/WSServiceBinding.h
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/model/WSServiceBinding.h?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/Axis2Service.cpp (original)
+++ incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/Axis2Service.cpp Wed Sep 20 22:27:54 2006
@@ -296,7 +296,7 @@
                         try {
                             wsdlOperation =  wsdlDefinition->findOperation(
                                 binding->getServiceName(),
-                                binding->getPortName(),
+                                binding->getEndpointName(),
                                 op_name);
                         }
                         catch(SystemConfigurationException &ex)

Modified: incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/WSReferenceBindingExtension.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/WSReferenceBindingExtension.cpp?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/WSReferenceBindingExtension.cpp (original)
+++ incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/WSReferenceBindingExtension.cpp Wed Sep 20 22:27:54 2006
@@ -71,9 +71,19 @@
                 if (bindingType == "WebServiceBinding")
                 {
                     string uri = scdlBinding->getCString("uri");
-                    string port = scdlBinding->getCString("port");
+                    string endpoint = scdlBinding->getCString("endpoint");
+                   commonj::sdo::DataObjectList& soap = scdlBinding->getList("soapbinding");
+                    string version;
+                    if (soap.size()!=0)
+                    {
+                        version = soap.getCString(0);
+                    }
+                    else
+                    {
+                        version = "";
+                    }
 
-                    WSReferenceBinding* serviceBinding = new WSReferenceBinding(reference, uri, port);
+                    WSReferenceBinding* serviceBinding = new WSReferenceBinding(reference, uri, endpoint, version);
                     
                     return serviceBinding;
                 }

Modified: incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/model/WSReferenceBinding.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/model/WSReferenceBinding.cpp?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/model/WSReferenceBinding.cpp (original)
+++ incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/model/WSReferenceBinding.cpp Wed Sep 20 22:27:54 2006
@@ -30,57 +30,57 @@
         {
 
             // Constructor
-            WSReferenceBinding::WSReferenceBinding(Reference* reference, const string& uri, const string& port)
-                : ReferenceBinding(reference, uri), port(port)
+            WSReferenceBinding::WSReferenceBinding(Reference* reference, const string& uri, const string& endpoint, const string&version)
+                : ReferenceBinding(reference, uri), endpoint(endpoint), soapVersion(version)
             {
-                parsePort();
+                parseEndpoint();
             }
             
-            void WSReferenceBinding::parsePort()
+            void WSReferenceBinding::parseEndpoint()
             {
-                // Port is of the form: <wsdl-namepace-uri>#wsdl.endpoint(<service-name>/<port-name>)
-                string::size_type hash = port.find("#");
+                // Endpoint is of the form: <wsdl-namepace-uri>#wsdl.endpoint(<service-name>/<endpoint-name>)
+                string::size_type hash = endpoint.find("#");
                 if (hash != string::npos)
                 {
                     // Found a hash
 
                     // Namepace is the part before the #
-                    wsdlNamespaceURL = port.substr(0, hash);
+                    wsdlNamespaceURL = endpoint.substr(0, hash);
 
                     
-                    if ( (hash+1) < port.length())
+                    if ( (hash+1) < endpoint.length())
                     {
                         // Check the next part is wsdl.endpoint( 
                         int ending = hash+15;
-                        string check = port.substr(hash+1, 14);
+                        string check = endpoint.substr(hash+1, 14);
                         if (check.compare("wsdl.endpoint(") == 0)
                         {
                             // Find the matching )
-                            int endBracket = port.find(")",ending);
+                            int endBracket = endpoint.find(")",ending);
                             if (endBracket-1 > ending+1)
                             {
-                                string serviceAndPort = port.substr(ending, endBracket-ending);
+                                string serviceAndEndpoint = endpoint.substr(ending, endBracket-ending);
                                 // Look for a '/'
-                                string::size_type slash = serviceAndPort.find("/");
+                                string::size_type slash = serviceAndEndpoint.find("/");
                                 if (slash != string::npos)
                                 {
-                                    serviceName = serviceAndPort.substr(0, slash);
+                                    serviceName = serviceAndEndpoint.substr(0, slash);
 
-                                    if ( (slash+1) < serviceAndPort.length())
+                                    if ( (slash+1) < serviceAndEndpoint.length())
                                     {
-                                        portName = serviceAndPort.substr(slash+1);
+                                        endpointName = serviceAndEndpoint.substr(slash+1);
                                     }
                                     else
                                     {
-                                        portName = "";
+                                        endpointName = "";
                                     }
 
                                 }
                                 else
                                 {
                                     // No '/' so all of it is the service name
-                                    serviceName = serviceAndPort;
-                                    portName = "";
+                                    serviceName = serviceAndEndpoint;
+                                    endpointName = "";
 
                                 }
                             }
@@ -88,14 +88,14 @@
                             {
                                 // Nothing between the ()
                                 serviceName = "";
-                                portName = "";
+                                endpointName = "";
                             }
                         }
                         else
                         {
                             // not the correct characters after the #, ignore the rest
                             serviceName = "";
-                            portName = "";
+                            endpointName = "";
                         }
                         
                     }
@@ -103,15 +103,15 @@
                     {
                         // Nothing after the hash
                         serviceName = "";
-                        portName = "";
+                        endpointName = "";
                     }
                 }
                 else
                 {
                     // No hash at all
-                    wsdlNamespaceURL = port;
+                    wsdlNamespaceURL = endpoint;
                     serviceName = "";
-                    portName = "";
+                    endpointName = "";
                 }
             }
 

Modified: incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/model/WSReferenceBinding.h
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/model/WSReferenceBinding.h?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/extensions/ws/xsd/sca-binding-webservice.xsd (original)
+++ incubator/tuscany/cpp/sca/runtime/extensions/ws/xsd/sca-binding-webservice.xsd Wed Sep 20 22:27:54 2006
@@ -24,11 +24,28 @@
         <complexContent>
             <extension base="sca:Binding">
                 <sequence>
+	                <element name="soapbinding" type="sca:SOAPBinding" minOccurs="0" maxOccurs="unbounded"/>
                     <any namespace="##other" processContents="lax" minOccurs="0" maxOccurs="unbounded" />
                 </sequence>
-                <attribute name="port" type="anyURI" use="optional" />
+                <attribute name="endpoint" type="anyURI" use="optional" />
+                <attribute name="location" type="anyURI" use="optional" />
+                <attribute name="conformanceURIs" type="sca:ConformanceURIList" use="optional" />
+                <attribute name="interfaceMapping" type="string" use="optional" />
                 <anyAttribute namespace="##any" processContents="lax" />
             </extension>
         </complexContent>
     </complexType>
+    
+    <complexType name="SOAPBinding">
+        <sequence>
+            <any namespace="##other" processContents="lax" minOccurs="0" maxOccurs="unbounded" />
+        </sequence>
+        <attribute name="name" type="NCName" use="optional" />
+        <attribute name="version" type="string" use="optional" />
+		<anyAttribute namespace="##any" processContents="lax" />
+    </complexType>
+    
+	<simpleType name="ConformanceURIList">
+		<list itemType="anyURI"/>
+	</simpleType>
 </schema>

Modified: incubator/tuscany/cpp/sca/samples/BigBank/bigbank.account/bigbank.account.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/BigBank/bigbank.account/bigbank.account.composite?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/samples/BigBank/bigbank.account/bigbank.account.composite (original)
+++ incubator/tuscany/cpp/sca/samples/BigBank/bigbank.account/bigbank.account.composite Wed Sep 20 22:27:54 2006
@@ -19,8 +19,8 @@
 
 	<service name="AccountService">
 		<interface.wsdl interface="http://www.bigbank.com/AccountService#wsdl.interface(AccountService)"/>
-		<!--  The port is optional -->
-		<!--  <binding.ws port="http://www.bigbank.com/AccountService#wsdl.endpoint(AccountService/AccountServiceSOAP)"/> -->
+		<!--  The endpoint is optional -->
+		<!--  <binding.ws endpoint="http://www.bigbank.com/AccountService#wsdl.endpoint(AccountService/AccountServiceSOAP)"/> -->
 		<binding.ws/>
 		<reference>AccountServiceComponent</reference>
 	</service>
@@ -43,7 +43,7 @@
 
 	<reference name="StockQuoteWebService">
 		<interface.wsdl interface="http://www.webserviceX.NET/#wsdl.interface(StockQuoteSoap)"/>
-		<binding.ws port="http://www.webserviceX.NET/#wsdl.endpoint(StockQuote/StockQuoteSoap)"/>
+		<binding.ws endpoint="http://www.webserviceX.NET/#wsdl.endpoint(StockQuote/StockQuoteSoap)"/>
 	</reference>
 
 </composite>

Modified: incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/sca.composite?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/sca.composite (original)
+++ incubator/tuscany/cpp/sca/samples/MyValue/MyValueComposite/sca.composite Wed Sep 20 22:27:54 2006
@@ -23,7 +23,7 @@
 	<!-- Expose as a web service -->
 	<entryPoint name="MyValueService" multiplicity="1..1">
 		<interface.wsdl interface="MyValue/MyValueService.wsdl" callbackInterface=""></interface.wsdl>
-		<binding.ws port="mvs:MyValueServiceBinding"></binding.ws>
+		<binding.ws endpoint="mvs:MyValueServiceBinding"></binding.ws>
 		<reference>MyValueServiceComponent</reference>
 	</entryPoint>
 
@@ -39,7 +39,7 @@
 
 	<externalService name="StockQuoteService">
 		<interface.cpp header="StockQuoteService/StockQuoteService.h"/>
-		<binding.ws port="http://swanandmokashi.com#wsdl.endpoint(StockQuotes/StockQuotesSoap)"/>
+		<binding.ws endpoint="http://swanandmokashi.com#wsdl.endpoint(StockQuotes/StockQuotesSoap)"/>
 	</externalService>
 
 	<!--wire>

Modified: incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator/sample.calculator.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator/sample.calculator.composite?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator/sample.calculator.composite (original)
+++ incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator/sample.calculator.composite Wed Sep 20 22:27:54 2006
@@ -19,8 +19,8 @@
 	name="sample.calculator">
 
 	<service name="CalculatorService">
-		<interface.wsdl interface="http://sample/calculator#wsdl.interface(CalculatorPortType)"/>
-		<binding.ws port="http://sample/calculator#wsdl.endpoint(CalculatorService/CalculatorPort)"/>
+		<interface.wsdl interface="http://sample/calculator#wsdl.interface(Calculator)"/>
+		<binding.ws/>
 		<reference>CalculatorComponent</reference>
 	</service>
 

Modified: incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.demo/supplychain.demo.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.demo/supplychain.demo.composite?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.demo/supplychain.demo.composite (original)
+++ incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.demo/supplychain.demo.composite Wed Sep 20 22:27:54 2006
@@ -25,13 +25,13 @@
 
 	<reference name="retailer">
 		<interface.wsdl interface="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Retailer.wsdl#wsdl.interface(RetailerPortType)"/>
-		<binding.ws port="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Retailer.wsdl#wsdl.endpoint(RetailerService/RetailerPort)"
+		<binding.ws endpoint="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Retailer.wsdl#wsdl.endpoint(RetailerService/RetailerPort)"
 			uri="http://localhost:9090/axis2/services/supplychain.retailer.solution/RetailerService"/>
 	</reference>
 
 	<reference name="logging">
 		<interface.wsdl interface="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/LoggingFacility.wsdl#wsdl.interface(LoggingFacilityLogPortType)"/>
-		<binding.ws port="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/LoggingFacility.wsdl#wsdl.endpoint(LoggingFacilityService/LoggingFacilityPort)"/>
+		<binding.ws endpoint="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/LoggingFacility.wsdl#wsdl.endpoint(LoggingFacilityService/LoggingFacilityPort)"/>
 	</reference>
 
 </composite>

Modified: incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.logging/supplychain.logging.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.logging/supplychain.logging.composite?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.logging/supplychain.logging.composite (original)
+++ incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.logging/supplychain.logging.composite Wed Sep 20 22:27:54 2006
@@ -19,7 +19,7 @@
 
 	<service name="LoggingService">
 		<interface.wsdl interface="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/LoggingFacility.wsdl#wsdl.interface(LoggingFacilityLogPortType)"/>
-		<binding.ws port="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/LoggingFacility.wsdl#wsdl.endpoint(LoggingFacilityService/LoggingFacilityPort)"/>
+		<binding.ws endpoint="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/LoggingFacility.wsdl#wsdl.endpoint(LoggingFacilityService/LoggingFacilityPort)"/>
 		<reference>Logger/Logging</reference>
 	</service>
 

Modified: incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.manufacturer/supplychain.manufacturer.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.manufacturer/supplychain.manufacturer.composite?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.manufacturer/supplychain.manufacturer.composite (original)
+++ incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.manufacturer/supplychain.manufacturer.composite Wed Sep 20 22:27:54 2006
@@ -20,7 +20,7 @@
 
 	<service name="ManufacturerService">
 		<interface.wsdl interface="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-10/Manufacturer.wsdl#wsdl.interface(ManufacturerPortType)"/>
-		<binding.ws port="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-10/Manufacturer.wsdl#wsdl.endpoint(ManufacturerService/ManufacturerPort)"/>
+		<binding.ws endpoint="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-10/Manufacturer.wsdl#wsdl.endpoint(ManufacturerService/ManufacturerPort)"/>
 		<reference>ManufacturerProcess/ManufacturerService</reference>
 	</service>
 	
@@ -35,12 +35,12 @@
 
 	<reference name="logging">
 		<interface.wsdl interface="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/LoggingFacility.wsdl#wsdl.interface(LoggingFacilityLogPortType)"/>
-		<binding.ws port="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/LoggingFacility.wsdl#wsdl.endpoint(LoggingFacilityService/LoggingFacilityPort)"/>
+		<binding.ws endpoint="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/LoggingFacility.wsdl#wsdl.endpoint(LoggingFacilityService/LoggingFacilityPort)"/>
 	</reference>
 
 	<reference name="callback">
 		<interface.wsdl interface="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-10/Manufacturer.wsdl#wsdl.interface(WarehouseCallbackPortType)"/>
-		<binding.ws port="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-10/Manufacturer.wsdl#wsdl.endpoint(WarehouseCallbackService/WarehouseCallbackPort)"/>
+		<binding.ws endpoint="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-10/Manufacturer.wsdl#wsdl.endpoint(WarehouseCallbackService/WarehouseCallbackPort)"/>
 	</reference>
 	
 </composite>

Modified: incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.retailer/supplychain.retailer.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.retailer/supplychain.retailer.composite?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.retailer/supplychain.retailer.composite (original)
+++ incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.retailer/supplychain.retailer.composite Wed Sep 20 22:27:54 2006
@@ -19,7 +19,7 @@
 
 	<service name="RetailerService">
 		<interface.wsdl interface="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Retailer.wsdl#wsdl.interface(RetailerPortType)"/>
-		<binding.ws port="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Retailer.wsdl#wsdl.endpoint(RetailerService/RetailerPort)"/>
+		<binding.ws endpoint="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Retailer.wsdl#wsdl.endpoint(RetailerService/RetailerPort)"/>
 		<reference>RetailerProcess/RetailerService</reference>
 	</service>
 
@@ -31,12 +31,12 @@
 
 	<reference name="warehouses" multiplicity="0..n">
 		<interface.wsdl interface="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Warehouse.wsdl#wsdl.interface(WarehouseShipmentsPortType)"/>
-		<binding.ws port="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Warehouse.wsdl#wsdl.endpoint(WarehouseShipmentsService/WarehouseShipmentsPort)"/>
+		<binding.ws endpoint="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Warehouse.wsdl#wsdl.endpoint(WarehouseShipmentsService/WarehouseShipmentsPort)"/>
 	</reference>
 
 	<reference name="logging">
 		<interface.wsdl interface="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/LoggingFacility.wsdl#wsdl.interface(LoggingFacilityLogPortType)"/>
-		<binding.ws port="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/LoggingFacility.wsdl#wsdl.endpoint(LoggingFacilityService/LoggingFacilityPort)"/>
+		<binding.ws endpoint="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/LoggingFacility.wsdl#wsdl.endpoint(LoggingFacilityService/LoggingFacilityPort)"/>
 	</reference>
 
 </composite>

Modified: incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.warehouse/supplychain.warehouse.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.warehouse/supplychain.warehouse.composite?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.warehouse/supplychain.warehouse.composite (original)
+++ incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.warehouse/supplychain.warehouse.composite Wed Sep 20 22:27:54 2006
@@ -20,13 +20,13 @@
 	
 	<service name="WarehouseService">
 		<interface.wsdl interface="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Warehouse.wsdl#wsdl.interface(WarehouseShipmentsPortType)"/>
-		<binding.ws port="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Warehouse.wsdl#wsdl.endpoint(WarehouseService/WarehousePort)"/>
+		<binding.ws endpoint="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Warehouse.wsdl#wsdl.endpoint(WarehouseService/WarehousePort)"/>
 		<reference>WarehouseProcess/WarehouseService</reference>
 	</service>
 	
 	<service name="WarehouseCallbackService">
 		<interface.wsdl interface="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-10/Manufacturer.wsdl#wsdl.interface(WarehouseCallbackPortType)"/>
-		<binding.ws port="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-10/Manufacturer.wsdl#wsdl.endpoint(WarehouseCallbackService/WarehouseCallbackPort)"/>
+		<binding.ws endpoint="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-10/Manufacturer.wsdl#wsdl.endpoint(WarehouseCallbackService/WarehouseCallbackPort)"/>
 		<reference>WarehouseCallbackProcess/WarehouseCallbackService</reference>
 	</service>
 	
@@ -47,12 +47,12 @@
 	
 	<reference name="manufacturer">
 		<interface.wsdl interface="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-10/Manufacturer.wsdl#wsdl.interface(ManufacturerPortType)"/>
-		<binding.ws port="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-10/Manufacturer.wsdl#wsdl.endpoint(ManufacturerService/ManufacturerPort)"/>
+		<binding.ws endpoint="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-10/Manufacturer.wsdl#wsdl.endpoint(ManufacturerService/ManufacturerPort)"/>
 	</reference>
 	
 	<reference name="logging">
 		<interface.wsdl interface="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/LoggingFacility.wsdl#wsdl.interface(LoggingFacilityLogPortType)"/>
-		<binding.ws port="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/LoggingFacility.wsdl#wsdl.endpoint(LoggingFacilityService/LoggingFacilityPort)"/>
+		<binding.ws endpoint="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/LoggingFacility.wsdl#wsdl.endpoint(LoggingFacilityService/LoggingFacilityPort)"/>
 	</reference>
 	
 </composite>



---------------------------------------------------------------------
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org
--- incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/model/WSServiceBinding.h (original)
+++ incubator/tuscany/cpp/sca/runtime/extensions/ws/reference/axis2c/src/tuscany/sca/ws/model/WSServiceBinding.h Wed Sep 20 22:27:54 2006
@@ -42,11 +42,11 @@
                 /**
                  * Constructor.
                  * @param uri The uri of the binding.
-                 * @param port The definition of the port to which the entrypoint
-                 * or external service is to be bound. This is of the form
-                 * "namespace"#endpoint("service"/"port")
+                 * @param endpoint The definition of the endpoint to which the service
+                 * or reference is to be bound. This is of the form
+                 * "namespace"#endpoint("service"/"endpoint")
                  */
-                WSServiceBinding(model::Service* service, const string& uri, const string& port);  
+                WSServiceBinding(model::Service* service, const string& uri, const string& endpoint, const string& version);  
 
                 /**
                  * Destructor.
@@ -65,50 +65,61 @@
                  virtual ServiceWrapper* getServiceWrapper();
                                 
                 /**
                  * Return the part of the port definition describing the wsdl 
                  * namespace.
                  * @return The wsdl namespace.
                  */
                 string getWSDLNamespaceURL() const { return wsdlNamespaceURL; };
 
                 /**
                  * Return the service part of the port definition.
                  * @return The service to use.
                  */
                 string getServiceName() const { return serviceName; };
 
                 /**
                  * Return the port name part of the port definition.
                  * @return The port name to use.
                  */
-                string getPortName() const { return portName; };
+                string getEndpointName() const { return endpointName; };
+                
+                /**
+                 * Return the SOAP version.
+                 * @return The SOAP version to use.
+                 */
+                string getSOAPVersion() const { return soapVersion; };
                 
             private:
             
                 /**
                  * Parse the port specification.
                  */
-                void parsePort();
+                void parseEndpoint();
             
                 /**
                  * The full port string.
                  */
-                string port;
+                string endpoint;
 
                 /**
                  * Namespace from the port.
                  */
                 string wsdlNamespaceURL;
 
                 /**
                  * Service name from the port.
                  */
                 string serviceName;
 
                 /**
-                 * Port name from the port.
+                 * WSDL Endpoint name.
+                 */
+                string endpointName;
+
+                /**
+                 * SOAP version.
                  */
-                string portName;
+                string soapVersion;
 
                 /**
                  * The wrapper for the service configured by this binding.
@@ -65,50 +65,61 @@
                                 
                 /**
-                 * Return the part of the port definition describing the wsdl 
+                 * Return the part of the endpoint definition describing the wsdl 
                  * namespace.
                  * @return The wsdl namespace.
@@ -65,50 +65,61 @@
 
                 /**
-                 * Return the service part of the port definition.
+                 * Return the service part of the endpoint definition.
                  * @return The service to use.
                  */
@@ -65,50 +65,61 @@
 
                 /**
-                 * Return the port name part of the port definition.
-                 * @return The port name to use.
+                 * Return the endpoint name part of the endpoint definition.
+                 * @return The endpoint name to use.
                  */
@@ -65,50 +65,61 @@
             
                 /**
-                 * Parse the port specification.
+                 * Parse the endpoint specification.
                  */
@@ -65,50 +65,61 @@
             
                 /**
-                 * The full port string.
+                 * The full endpoint string.
                  */
@@ -65,50 +65,61 @@
 
                 /**
-                 * Namespace from the port.
+                 * Namespace from the endpoint.
                  */
                 string wsdlNamespaceURL;
@@ -65,50 +65,61 @@
 
                 /**
-                 * Service name from the port.
+                 * Service name from the endpoint.
                  */
                 string serviceName;

Modified: incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/Axis2Service.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/Axis2Service.cpp?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/model/WSReferenceBinding.h (original)
+++ incubator/tuscany/cpp/sca/runtime/extensions/ws/service/axis2c/src/tuscany/sca/ws/model/WSReferenceBinding.h Wed Sep 20 22:27:54 2006
@@ -43,11 +43,11 @@
                 /**
                  * Constructor.
                  * @param uri The uri of the binding.
                  * @param port The definition of the port to which the entrypoint
                  * or external service is to be bound. This is of the form
-                 * "namespace"#endpoint("service"/"port")
+                 * "namespace"#endpoint("service"/"endpoint")
                  */
-                WSReferenceBinding(Reference* reference, const string&uri, const string& port);  
+                WSReferenceBinding(Reference* reference, const string&uri, const string& endpoint, const string& version);  
 
                 /**
                  * Destructor.
@@ -71,23 +71,29 @@
                  virtual ServiceProxy* getServiceProxy();
                                 
                 /**
                  * Return the part of the port definition describing the wsdl 
                  * namespace.
                  * @return The wsdl namespace.
                  */
                 string getWSDLNamespaceURL() const { return wsdlNamespaceURL; };
 
                 /**
                  * Return the service part of the port definition.
                  * @return The service to use.
                  */
                 string getServiceName() const { return serviceName; };
 
                 /**
                  * Return the port name part of the port definition.
                  * @return The port name to use.
                  */
-                string getPortName() const { return portName; };
+                string getEndpointName() const { return endpointName; };
+                
+                /**
+                 * Return the SOAP version.
+                 * @return The SOAP version to use.
+                 */
+                string getSOAPVersion() const { return soapVersion; };
                 
                  /**
                   * Returns the target service binding.
@@ -97,29 +103,34 @@
             private:
             
                 /**
                  * Parse the port specification.
                  */
-                void parsePort();
+                void parseEndpoint();
             
                 /**
                  * The full port string.
                  */
-                string port;
+                string endpoint;
 
                 /**
                  * Namespace from the port.
                  */
                 string wsdlNamespaceURL;
 
                 /**
                  * Service name from the port.
                  */
                 string serviceName;
 
                 /**
-                 * Port name from the port.
+                 * Endpoint name from the endpoint.
+                 */
+                string endpointName;
+
+                /**
+                 * SOAP version.
                  */
-                string portName;
+                string soapVersion;
 
                 /**
                  * The proxy representing the reference to the client
@@ -43,11 +43,11 @@
                  * Constructor.
                  * @param uri The uri of the binding.
-                 * @param port The definition of the port to which the entrypoint
+                 * @param endpoint The definition of the endpoint to which the entrypoint
                  * or external service is to be bound. This is of the form
@@ -71,23 +71,29 @@
                                 
                 /**
-                 * Return the part of the port definition describing the wsdl 
+                 * Return the part of the endpoint definition describing the wsdl 
                  * namespace.
                  * @return The wsdl namespace.
@@ -71,23 +71,29 @@
 
                 /**
-                 * Return the service part of the port definition.
+                 * Return the service part of the endpoint definition.
                  * @return The service to use.
                  */
@@ -71,23 +71,29 @@
 
                 /**
-                 * Return the port name part of the port definition.
-                 * @return The port name to use.
+                 * Return the endpoint name part of the endpoint definition.
+                 * @return The endpoint name to use.
                  */
@@ -97,29 +103,34 @@
             
                 /**
-                 * Parse the port specification.
+                 * Parse the endpoint specification.
                  */
@@ -97,29 +103,34 @@
             
                 /**
-                 * The full port string.
+                 * The full endpoint string.
                  */
@@ -97,29 +103,34 @@
 
                 /**
-                 * Namespace from the port.
+                 * Namespace from the endpoint.
                  */
                 string wsdlNamespaceURL;
@@ -97,29 +103,34 @@
 
                 /**
-                 * Service name from the port.
+                 * Service name from the endpoint.
                  */
                 string serviceName;

Modified: incubator/tuscany/cpp/sca/runtime/extensions/ws/xsd/sca-binding-webservice.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/extensions/ws/xsd/sca-binding-webservice.xsd?view=diff&rev=448463&r1=448462&r2=448463
==============================================================================